Cache tools

Description:
------------
Module introduces couple of improvements to default Drupal cache behavior.

Features:
---------

### 1. Sanitizing cache tags.

Module allows to sanitize cache tags and contexts for listed blocks.
It's using custom BlockViewBuilder to sanitize tags and contexts of blocks.
By default it's stripping several contexts (route, url, url.query_args)
and couple of tags (node_list, taxonomy_term_list). You can also decide
which additional tags and contexts you would like to strip. Everything
is configured in cache_tools.services.yml under paramter section.
You can override parameters by introducing custom services.yml

### 2. Custom cache tag for views.

Module introduces also custom cache tag for the views. It's optimizing
to place more precise tags for the views. Namely, it places
`{entity}_{bundle}_pub` (like `node_article_pub` or `node_recipe_pub`)
instead of too genereal `node_list`. By doing so it will handle invalidation
of published nodes only respecting the bundle of the node. This tag is placed
out-of-the-box based on the view configuration. Module is auto extracting
the filter and arguments handler settings for particular view. If there is
such handler it will auto identify entity and bundle and set\
`{entity}_{bundle}_pub` tag. Invalidation is handled automatically during
entity_insert and entity_update events.

### 2. Custom cache tag for views based on field.

You can also use extended version of the cache tag behavior, namely you can
additionally set the field to be included in cache tag. Along the entity id.
You can achieve this by using cache tag for views based on field, where
you can select which field will be contained in that cache tags. As an example,
let's say you'll choose the field `field_author`, then instead of regular
`node_article_pub` you'll get `node_article_pub:field_author:123`. Where 123 is
the node id of currently previewed entity.

Use case for this:
1. You have author/user entity
2. On the author/user page you'll see list of content of this author/user
3. List (or view) should be invalidated only when this author/user is assigned
to some new published content. In case of updating the published content,
both previous and current author/user page should be invalidated.
4. Placing tags like `node_article_pub:field_author:{author_id}` is excellent
way to deal with the problem. Everytime the new content is added which contain
this author, you invalidate `node_article_pub:field_author:123` so only page
of author/user 123 will be invalidated.

**NOTE:** Module is only placing the tag in this case. The invalidation
behavior needs to be handled in custom module. Module cannot know how you
field is behaving and when you really want to invalidate such a page.
Example of custom hook on `entity_insert`:

```php
/**
 * Implements hook_entity_insert().
 *
 * Invalidates by field author. Only if field is set and node is published.
 */
function module_entity_insert(EntityInterface $entity) {
  // If new entity us upublished there is nothing to invalidate.
  if (empty($entity->status->value)) {
    return;
  }
  // If author is not filled there is nothing to invalidate.
  if (empty($entity->field_author->entity)) {
    return;
  }
  $tag = 'node_' . $entity->bundle() . '_pub:field_author:' 
  . $entity->field_author->entity->id();
  /** @var \Drupal\Core\Cache\CacheTagsInvalidator $tags_invalidator */
  $tags_invalidator = \Drupal::service('cache_tags.invalidator');
  $tags_invalidator->invalidateTags([$tag]);
}
```
